Quadrature
==========

Base classes
------------

.. automodule:: modepy.quadrature

.. currentmodule:: modepy

.. autoclass:: Quadrature

    .. automethod:: __call__

Jacobi-Gauss quadrature
-----------------------

.. automodule:: modepy.quadrature.jacobi_gauss

.. currentmodule:: modepy

.. autoclass:: JacobiGaussQuadrature

    .. automethod:: __call__

.. autoclass:: LegendreGaussQuadrature

    .. automethod:: __call__

.. currentmodule:: modepy.quadrature.jacobi_gauss

.. autofunction:: jacobi_gauss_lobatto_nodes

.. autofunction:: legendre_gauss_lobatto_nodes

Quadratures on the simplex
--------------------------

.. currentmodule:: modepy

.. autoclass:: GrundmannMoellerSimplexQuadrature

    .. automethod:: __call__

.. autoclass:: XiaoGimbutasSimplexQuadrature

    .. automethod:: __call__

.. vim: sw=4


